@@ -299,7 +299,8 @@ class Builder(Update):
 
     def syncRepositories(self, repname, clean_on_error=True):
         with self.clVars.useDefaultModule("update"):
-            return super(Builder, self).syncRepositories(repname)
+            return super(Builder, self).syncRepositories(
+                repname, clean_on_error=clean_on_error)
 
     def _regenCache_process(self, progname, repname, cpu_num):
         chroot_path = self.clVars.Get('builder.cl_builder_path')
@@ -1229,7 +1230,11 @@ class Builder(Update):
             if current_video == video and video != "default":
                 composite = self.clVars.Get('cl_builder_x11_composite')
                 params.append("%s:%s" % (CmdlineParams.Composite, composite))
-        return ",".join(params)
+        calculate_param = ",".join(params)
+        if self.clVars.GetBool('cl_builder_docache_set'):
+            return "%s docache" % calculate_param
+        else:
+            return calculate_param
 
     def create_iso_grub_cfg(self, dn):
         gc = GrubCommand()
@@ -1314,3 +1319,4 @@ class Builder(Update):
             clVars.close()
             self.endTask()
         return True
+
