@@ -141,6 +141,15 @@ class ClBuilderUpdateAction(Action):
                       'condition': lambda Get: Get(
                           'update.cl_update_other_set') == 'on'
                       },
+                     {'name': 'trim_reps',
+                      'foreach': 'cl_builder_sync_rep',
+                      'message': __("Cleaning the history of the "
+                                    "{eachvar:capitalize} repository"),
+                      'method': 'Builder.trimRepositories(eachvar)',
+                      'condition': lambda Get: (
+                          Get('cl_builder_sync_rep') and
+                          Get('update.cl_update_onedepth_set') == 'on')
+                      },
                      {'name': 'regen_cache',
                       'foreach': 'cl_builder_sync_overlay_rep',
                       'essential': False,
