@@ -190,7 +190,9 @@ class Wsdl(WsdlBase):
                         'cl_builder_rebuild_changed_set',
                         'update.cl_update_skip_rb_set',
                         'update.cl_update_binhost_recheck_set',
+                        'update.cl_update_onedepth_set',
                         'update.cl_update_cleanpkg_set',
+                        'update.cl_update_check_rep_set',
                         'cl_builder_branch_data',
                         'cl_templates_locate',
                         'cl_verbose_set',
@@ -240,6 +242,7 @@ class Wsdl(WsdlBase):
                                         'cl_builder_x11_video_drv',
                                         'cl_builder_x11_resolution',
                                         'cl_builder_x11_composite',
+                                        'cl_builder_docache_set'
                                     ),
                                     next_label=_("Perform"))],
             'brief': {'next': __("Perform"),
@@ -339,7 +342,6 @@ class Wsdl(WsdlBase):
                                           'cl_builder_videodrv_set',
                                           'cl_builder_compress',
                                           'cl_builder_keep_tree_set',
-                                          'cl_builder_live_set',
                                           'cl_builder_isohybrid_set',
                                           'cl_builder_prelink_set',
                                           ),
@@ -347,11 +349,12 @@ class Wsdl(WsdlBase):
                                         # Включить проприетарные видео драйвера
                                         # Include proprietary video drivers
                                         'cl_builder_videodrv_set',
-                                        'cl_builder_compress',
+                                        'update.cl_update_onedepth_set',
                                         'cl_builder_keep_tree_set',
                                         'cl_builder_live_set',
                                         'cl_builder_isohybrid_set',
                                         'cl_builder_prelink_set',
+                                        'cl_builder_compress',
                                         'cl_templates_locate',
                                         'cl_verbose_set',
                                         'cl_dispatch_conf'),
